@@ -211,21 +211,9 @@ private:
 // property_lookup
 
 /** \brief Encapsulates the lookup process for connected properties
-	\note Breaks circular dependencies by returning the original property
+	\note In the case of circular dependencies, returns the same value as the input property
 */
-inline iproperty* property_lookup(iproperty* const Source, idag& DAG)
-{
-	iproperty* result = Source;
-	for(iproperty* dependency = DAG.dependency(*Source); dependency; dependency = DAG.dependency(*dependency))
-	{
-		result = dependency;
-
-		if(Source == dependency)
-			break;
-	}
-
-	return result;
-}
+iproperty* property_lookup(iproperty* const Source, idag& DAG);
 
 /////////////////////////////////////////////////////////////////////////////
 // no_property
@@ -649,7 +637,7 @@ public:
 	{
 		m_pattern_filters.push_back(PatternFilter);
 	}
-	
+
 protected:
 	template<typename init_t>
 	path_property(const init_t& Init) :
