@@ -37,13 +37,14 @@ class irender_frame;
 namespace ri
 {
 
+class ishader_collection;
+
 /// Abstract binding to the Pixar RenderMan interface
 class irender_engine :
 	public virtual iunknown
 {
 public:
 	virtual bool set_inline_types(const bool Inline) = 0;
-	virtual void use_shader(const path& Path) = 0;
 
 	virtual const light_handle RiAreaLightSourceV(const path& Path, const string& Name, const parameter_list& Parameters = parameter_list()) = 0;
 	virtual void RiAtmosphereV(const path& Path, const string& Name, const parameter_list& Parameters = parameter_list()) = 0;
@@ -165,9 +166,10 @@ protected:
 /// Used to pass (potentially) useful rendering state from the engine to the object being rendered
 struct render_state
 {
-	render_state(irender_frame& Frame, irender_engine& Engine, iprojection& Projection, const render_context_t RenderContext, const sample_times_t& SampleTimes, const unsigned_integer SampleIndex, const matrix4& CameraMatrix) :
+	render_state(irender_frame& Frame, irender_engine& Engine, ishader_collection& Shaders, iprojection& Projection, const render_context_t RenderContext, const sample_times_t& SampleTimes, const unsigned_integer SampleIndex, const matrix4& CameraMatrix) :
 		frame(Frame),
 		engine(Engine),
+		shaders(Shaders),
 		projection(Projection),
 		render_context(RenderContext),
 		sample_times(SampleTimes),
@@ -178,6 +180,7 @@ struct render_state
 
 	irender_frame& frame;
 	irender_engine& engine;
+	ishader_collection& shaders;
 	iprojection& projection;
 	render_context_t render_context;
 	sample_times_t sample_times;
@@ -219,6 +222,7 @@ class irenderable :
 {
 public:
 	virtual void renderman_render(const render_state& State) = 0;
+	virtual void renderman_render_complete(const render_state& State) = 0;
 
 protected:
 	irenderable() {}
@@ -232,7 +236,7 @@ class itexture :
 	public virtual iunknown
 {
 public:
-	virtual void setup_renderman_texture(irender_frame& Frame, irender_engine& Engine) = 0;
+	virtual void setup_renderman_texture(irender_frame& Frame, irender_engine& Engine, ishader_collection& Shaders) = 0;
 	virtual const boost::filesystem::path renderman_texture_path(const render_state& State) = 0;
 
 protected:
