@@ -638,7 +638,7 @@ void set_options(iproperty_collection& Properties, irender_engine& Engine)
 	}
 
 	for(parameter_lists_t::iterator parameter_list = parameter_lists.begin(); parameter_list != parameter_lists.end(); ++parameter_list)
-		Engine.RiAttributeV(parameter_list->first, parameter_list->second);
+		Engine.RiOptionV(parameter_list->first, parameter_list->second);
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -672,8 +672,6 @@ public:
 	bool m_object_block;
 	/// Set to true within a motion block
 	bool m_motion_block;
-	/// Stores the set of shaders in-use
-	shaders_t m_shaders;
 };
 
 /////////////////////////////////////////////////////////////////////////////
@@ -698,21 +696,11 @@ render_engine::~render_engine()
 	delete m_implementation;
 }
 
-const render_engine::shaders_t render_engine::shaders()
-{
-	return m_implementation->m_shaders;
-}
-
 bool render_engine::set_inline_types(const bool Inline)
 {
 	return ::set_inline_types(m_implementation->m_stream, Inline);
 }
 
-void render_engine::use_shader(const path& Path)
-{
-	m_implementation->m_shaders.insert(Path);
-}
-
 void render_engine::RiDeclare(const string& Name, const string& Type)
 {
 	// Sanity checks ...
@@ -825,7 +813,6 @@ void render_engine::RiExposure(real Gain, real Gamma)
 
 void render_engine::RiImagerV(const path& Path, const string& Name, const parameter_list& Parameters)
 {
-	m_implementation->m_shaders.insert(Path);
 	m_implementation->m_stream << ::indentation << "Imager " << format_string(Name) << " " << Parameters << "\n";
 }
 
@@ -895,14 +882,12 @@ void render_engine::RiTextureCoordinates(real S1, real T1, real S2, real T2, rea
 
 const light_handle render_engine::RiLightSourceV(const path& Path, const string& Name, const parameter_list& Parameters)
 {
-	m_implementation->m_shaders.insert(Path);
 	m_implementation->m_stream << ::indentation << "LightSource " << format_string(Name) << " " << ++m_implementation->m_light_handle << " " << Parameters << "\n";
 	return m_implementation->m_light_handle;
 }
 
 const light_handle render_engine::RiAreaLightSourceV(const path& Path, const string& Name, const parameter_list& Parameters)
 {
-	m_implementation->m_shaders.insert(Path);
 	m_implementation->m_stream << ::indentation << "AreaLightSource " << format_string(Name) << " " << ++m_implementation->m_light_handle << " " << Parameters << "\n";
 	return m_implementation->m_light_handle;
 }
@@ -914,25 +899,21 @@ void render_engine::RiIlluminate(const light_handle LightHandle, bool OnOff)
 
 void render_engine::RiSurfaceV(const path& Path, const string& Name, const parameter_list& Parameters)
 {
-	m_implementation->m_shaders.insert(Path);
 	m_implementation->m_stream << ::indentation << "Surface " << format_string(Name) << " " << Parameters << "\n";
 }
 
 void render_engine::RiAtmosphereV(const path& Path, const string& Name, const parameter_list& Parameters)
 {
-	m_implementation->m_shaders.insert(Path);
 	m_implementation->m_stream << ::indentation << "Atmosphere " << format_string(Name) << " " << Parameters << "\n";
 }
 
 void render_engine::RiInteriorV(const path& Path, const string& Name, const parameter_list& Parameters)
 {
-	m_implementation->m_shaders.insert(Path);
 	m_implementation->m_stream << ::indentation << "Interior " << format_string(Name) << " " << Parameters << "\n";
 }
 
 void render_engine::RiExteriorV(const path& Path, const string& Name, const parameter_list& Parameters)
 {
-	m_implementation->m_shaders.insert(Path);
 	m_implementation->m_stream << ::indentation << "Exterior " << format_string(Name) << " " << Parameters << "\n";
 }
 
@@ -1033,13 +1014,11 @@ void render_engine::RiSkew(real Angle, real DX1, real DY1, real DZ1, real DX2, r
 
 void render_engine::RiDeformationV(const path& Path, const string& Name, const parameter_list& Parameters)
 {
-	m_implementation->m_shaders.insert(Path);
 	m_implementation->m_stream << ::indentation << "Deformation " << format_string(Name) << " " << Parameters << "\n";
 }
 
 void render_engine::RiDisplacementV(const path& Path, const string& Name, const parameter_list& Parameters)
 {
-	m_implementation->m_shaders.insert(Path);
 	m_implementation->m_stream << ::indentation << "Displacement " << format_string(Name) << " " << Parameters << "\n";
 }
 
@@ -1314,7 +1293,6 @@ void render_engine::RiBlobbyV(const unsigned_integer NLeaf, const unsigned_integ
 
 void render_engine::RiShaderLayerV(const std::string& type, const path& Path, const std::string& name, const std::string& layername, const parameter_list& Parameters)
 {
-	m_implementation->m_shaders.insert(Path);
 	m_implementation->m_stream << ::indentation << "ShaderLayer " << format_string(type) << " " << format_string(name) << " " << format_string(layername) << " " << Parameters << "\n";
 }
 
