@@ -64,6 +64,7 @@
 #include <k3dsdk/ienumeration_property.h>
 #include <k3dsdk/ilist_property.h>
 #include <k3dsdk/imeasurement_property.h>
+#include <k3dsdk/imesh_storage.h>
 #include <k3dsdk/inode.h>
 #include <k3dsdk/iplugin_factory.h>
 #include <k3dsdk/ipreview_render_engine.h>
@@ -121,7 +122,7 @@ public:
 	{
 		m_label.set_alignment(Gtk::ALIGN_LEFT);
 		m_label.set_padding(5, 5);
-		
+
 		&m_help_button << connect_button(sigc::mem_fun(*this, &implementation::on_online_help));
 
 		m_scrolled_window.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
@@ -276,6 +277,17 @@ public:
 			toolbar_control->row(0).pack_start(*Gtk::manage(control), Gtk::PACK_SHRINK);
 		}
 
+		// Add a "reset" button for nodes that implement k3d::imesh_storage (FrozenMesh, external file readers, etc) ...
+		if(dynamic_cast<k3d::imesh_storage*>(m_node))
+		{
+			button::control* const control =
+				new button::control(m_parent, "reset_mesh", _("Reset Mesh"))
+					<< connect_button(sigc::mem_fun(*this, &implementation::on_reset_mesh))
+					<< set_tooltip(_("Reset / Reload Mesh"));
+
+			toolbar_control->row(0).pack_start(*Gtk::manage(control), Gtk::PACK_SHRINK);
+		}
+
 		// Get the node properties, grouped together ...
 		k3d::iproperty_collection* const property_collection = dynamic_cast<k3d::iproperty_collection*>(m_node);
 		k3d::iproperty_group_collection::groups_t property_groups;
@@ -516,7 +528,7 @@ public:
 			open_uri("http://www.k-3d.org/wiki/" + m_node->factory().name());
 		}
 	}
-	
+
 	void on_render_camera_preview()
 	{
 		k3d::icamera* camera = dynamic_cast<k3d::icamera*>(m_node);
@@ -592,6 +604,14 @@ public:
 		render_animation(m_document_state, *render_engine);
 	}
 
+    void on_reset_mesh()
+    {
+            k3d::imesh_storage* const mesh_storage = dynamic_cast<k3d::imesh_storage*>(m_node);
+            return_if_fail(mesh_storage);
+
+            mesh_storage->reset_mesh(0);
+    }
+
 	void on_delete_user_property(k3d::iproperty_collection* Collection, k3d::iproperty* Property)
 	{
 		return_if_fail(Collection);
@@ -599,10 +619,10 @@ public:
 		return_if_fail(dynamic_cast<k3d::iuser_property*>(Property));
 
 		k3d::record_state_change_set change_set(m_document_state.document(), "Delete user property", __PRETTY_FUNCTION__);
-		
+
 		if(m_document_state.document().state_recorder().current_change_set())
 			m_document_state.document().state_recorder().current_change_set()->record_old_state(new k3d::user::property_container(*Collection));
-		
+
 		Collection->unregister_property(*Property);
 		if(k3d::ipersistent* const persistent = dynamic_cast<k3d::ipersistent*>(Property))
 		{
